@@ -1,7 +1,6 @@
 test_that("request helpers - building requests", {
-
   host <- "some_url"
-  token <-  "some_token"
+  token <- "some_token"
   endpoint <- "clusters/create"
   endpoint_version <- "2.0"
   method <- "POST"
@@ -27,12 +26,15 @@ test_that("request helpers - building requests", {
   expect_identical(req$body$data, body)
   expect_no_error(req$options$useragent)
   expect_equal(req$policies$retry_max_tries, 3)
-  expect_equal(req$headers$Authorization, paste("Bearer", token))
-
+  if (packageVersion("httr2") >= "1.2.0") {
+    headers <- httr2::req_get_headers(req, "reveal")
+  } else {
+    headers <- req$headers
+  }
+  expect_equal(headers$Authorization, paste("Bearer", token))
 
   req_json <- db_request_json(req)
   expect_equal(unclass(req_json), "{\"a\":1,\"b\":2}")
   expect_s3_class(req_json, "json")
   expect_null(db_request_json(NULL))
-
 })
